@@ -161,20 +161,29 @@ GType g_threaded_socket_service_get_type(void);
 #ifndef G_OS_WIN32
 GType g_unix_connection_get_type(void);
 #endif //G_OS_WIN32
+#ifndef G_OS_WIN32
 GType g_unix_credentials_message_get_type(void);
+#endif //G_OS_WIN32
+#ifndef G_OS_WIN32
 GType g_unix_fd_list_get_type(void);
+#endif //G_OS_WIN32
+#ifndef G_OS_WIN32
 GType g_unix_fd_message_get_type(void);
+#endif //G_OS_WIN32
 #ifndef G_OS_WIN32
 GType g_unix_input_stream_get_type(void);
 #endif //G_OS_WIN32
 #ifndef G_OS_WIN32
 GType g_unix_output_stream_get_type(void);
 #endif //G_OS_WIN32
+#ifndef G_OS_WIN32
 GType g_unix_socket_address_get_type(void);
+#endif //G_OS_WIN32
 GType g_volume_monitor_get_type(void);
 
 //Declarations of the *_error_quark() functions:
 
+GQuark g_dbus_error_quark(void);
 GQuark g_io_error_quark(void);
 GQuark g_resolver_error_quark(void);
 } // extern "C"
@@ -239,16 +248,24 @@ namespace Gio {  class ThreadedSocketService_Class { public: static Glib::Object
 #ifndef G_OS_WIN32
 namespace Gio {  class UnixConnection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #endif //G_OS_WIN32
+#ifndef G_OS_WIN32
 namespace Gio {  class UnixCredentialsMessage_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+#endif //G_OS_WIN32
+#ifndef G_OS_WIN32
 namespace Gio {  class UnixFDList_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+#endif //G_OS_WIN32
+#ifndef G_OS_WIN32
 namespace Gio {  class UnixFDMessage_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+#endif //G_OS_WIN32
 #ifndef G_OS_WIN32
 namespace Gio {  class UnixInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #endif //G_OS_WIN32
 #ifndef G_OS_WIN32
 namespace Gio {  class UnixOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #endif //G_OS_WIN32
+#ifndef G_OS_WIN32
 namespace Gio {  class UnixSocketAddress_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+#endif //G_OS_WIN32
 namespace Gio {  class VolumeMonitor_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 
 namespace Gio { 
@@ -256,6 +273,7 @@ namespace Gio {
 void wrap_init()
 {
   // Register Error domains:
+  Glib::Error::register_domain(g_dbus_error_quark(), &Gio::DBusError::throw_func);
   Glib::Error::register_domain(g_io_error_quark(), &Gio::Error::throw_func);
   Glib::Error::register_domain(g_resolver_error_quark(), &Gio::ResolverError::throw_func);
 
@@ -317,16 +335,24 @@ void wrap_init()
 #ifndef G_OS_WIN32
   Glib::wrap_register(g_unix_connection_get_type(), &Gio::UnixConnection_Class::wrap_new);
 #endif //G_OS_WIN32
+#ifndef G_OS_WIN32
   Glib::wrap_register(g_unix_credentials_message_get_type(), &Gio::UnixCredentialsMessage_Class::wrap_new);
+#endif //G_OS_WIN32
+#ifndef G_OS_WIN32
   Glib::wrap_register(g_unix_fd_list_get_type(), &Gio::UnixFDList_Class::wrap_new);
+#endif //G_OS_WIN32
+#ifndef G_OS_WIN32
   Glib::wrap_register(g_unix_fd_message_get_type(), &Gio::UnixFDMessage_Class::wrap_new);
+#endif //G_OS_WIN32
 #ifndef G_OS_WIN32
   Glib::wrap_register(g_unix_input_stream_get_type(), &Gio::UnixInputStream_Class::wrap_new);
 #endif //G_OS_WIN32
 #ifndef G_OS_WIN32
   Glib::wrap_register(g_unix_output_stream_get_type(), &Gio::UnixOutputStream_Class::wrap_new);
 #endif //G_OS_WIN32
+#ifndef G_OS_WIN32
   Glib::wrap_register(g_unix_socket_address_get_type(), &Gio::UnixSocketAddress_Class::wrap_new);
+#endif //G_OS_WIN32
   Glib::wrap_register(g_volume_monitor_get_type(), &Gio::VolumeMonitor_Class::wrap_new);
 
   // Register the gtkmm gtypes:
@@ -387,16 +413,24 @@ void wrap_init()
 #ifndef G_OS_WIN32
   Gio::UnixConnection::get_type();
 #endif //G_OS_WIN32
+#ifndef G_OS_WIN32
   Gio::UnixCredentialsMessage::get_type();
+#endif //G_OS_WIN32
+#ifndef G_OS_WIN32
   Gio::UnixFDList::get_type();
+#endif //G_OS_WIN32
+#ifndef G_OS_WIN32
   Gio::UnixFDMessage::get_type();
+#endif //G_OS_WIN32
 #ifndef G_OS_WIN32
   Gio::UnixInputStream::get_type();
 #endif //G_OS_WIN32
 #ifndef G_OS_WIN32
   Gio::UnixOutputStream::get_type();
 #endif //G_OS_WIN32
+#ifndef G_OS_WIN32
   Gio::UnixSocketAddress::get_type();
+#endif //G_OS_WIN32
   Gio::VolumeMonitor::get_type();
 
 } // wrap_init()
