@@ -18,17 +18,12 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <glibmmconfig.h>
 #include <glibmm/stringutils.h>
 #include <glibmm/utility.h>
 #include <glib.h>
 #include <cerrno>
 #include <stdexcept>
-#include <glibmmconfig.h>
-
-GLIBMM_USING_STD(out_of_range)
-GLIBMM_USING_STD(overflow_error)
-GLIBMM_USING_STD(underflow_error)
-
 
 bool Glib::str_has_prefix(const std::string& str, const std::string& prefix)
 {
@@ -52,11 +47,7 @@ double Glib::Ascii::strtod(const std::string&      str,
 {
   if(start_index > str.size())
   {
-    #ifdef GLIBMM_EXCEPTIONS_ENABLED
     throw std::out_of_range("out of range (strtod): start_index > str.size()");
-    #else
-      return 0;
-    #endif //GLIBMM_EXCEPTIONS_ENABLED
   }
 
   const char *const bufptr = str.c_str();
@@ -69,7 +60,6 @@ double Glib::Ascii::strtod(const std::string&      str,
   {
     g_return_val_if_fail(err_no == ERANGE, result);
 
-    #ifdef GLIBMM_EXCEPTIONS_ENABLED
     //Interpret the result in the event of an error:
     if(result > 0.0)
       throw std::overflow_error("overflow (strtod): positive number too large");
@@ -78,9 +68,6 @@ double Glib::Ascii::strtod(const std::string&      str,
       throw std::overflow_error("overflow (strtod): negative number too large");
 
     throw std::underflow_error("underflow (strtod): number too small");
-    #else
-    return result;
-    #endif // GLIBMM_EXCEPTIONS_ENABLED
   }
 
   if(endptr)
